import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';
const csvUrl =
'https://gist.githubusercontent.com/SharmilaChowdhari/e89030b3b3b10be1445750f4330b47c8/raw/1784b236a7fd5dc4f95ee189695abf4ab2f3397a/Movietitle'
const width = 700;
const height = 500;
const margin = { top: 20, right: 20, bottom: 50, left: 200 };
const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
       d.year = +d['2015'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 20));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.MovieType))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.year)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="skyblue" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.MovieType}
            x={0}
            y={yScale(d.MovieType)}
            fill="lightgreen"
            width={xScale(d.year)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);